@@ -281,8 +281,11 @@ next_image_cb (GtkWidget    *widget,
 #ifdef HAVE_LIBEXIF
 
 static ExifTag usefull_tags[] = {
+	/*
 	EXIF_TAG_RELATED_IMAGE_WIDTH,
 	EXIF_TAG_RELATED_IMAGE_LENGTH,
+	*/
+
 	EXIF_TAG_IMAGE_WIDTH,
 	EXIF_TAG_IMAGE_LENGTH,
 	EXIF_TAG_PIXEL_X_DIMENSION,
@@ -296,22 +299,24 @@ static ExifTag usefull_tags[] = {
 	EXIF_TAG_EXPOSURE_PROGRAM,
 	EXIF_TAG_EXPOSURE_MODE,
 	EXIF_TAG_EXPOSURE_BIAS_VALUE,
+	EXIF_TAG_FLASH,
+	EXIF_TAG_FLASH_ENERGY,
 	EXIF_TAG_SPECTRAL_SENSITIVITY,
 	EXIF_TAG_SHUTTER_SPEED_VALUE,
 	EXIF_TAG_APERTURE_VALUE,
 	EXIF_TAG_BRIGHTNESS_VALUE,
 	EXIF_TAG_LIGHT_SOURCE,
-	EXIF_TAG_FLASH,
-	EXIF_TAG_FLASH_ENERGY,
 	EXIF_TAG_FOCAL_LENGTH,
 	EXIF_TAG_WHITE_BALANCE,
 	EXIF_TAG_WHITE_POINT,
 	EXIF_TAG_DIGITAL_ZOOM_RATIO,
+	EXIF_TAG_SUBJECT_DISTANCE,
+	EXIF_TAG_SUBJECT_DISTANCE_RANGE,
+	EXIF_TAG_METERING_MODE,
 	EXIF_TAG_CONTRAST,
 	EXIF_TAG_SATURATION,
 	EXIF_TAG_SHARPNESS,
 	EXIF_TAG_FOCAL_LENGTH_IN_35MM_FILM,
-	EXIF_TAG_SUBJECT_DISTANCE_RANGE,
 	EXIF_TAG_BATTERY_LEVEL,
 
 	EXIF_TAG_DATE_TIME,
@@ -403,7 +408,7 @@ update_exif_data (DialogData *data)
 	for (i = 0; i < EXIF_IFD_COUNT; i++) {
 		ExifContent *content = edata->ifd[i];
 
-		if (! edata->ifd[i] || ! edata->ifd[i]->count) 
+		if ((content == NULL) || (content->count == 0)) 
 			continue;
 
 		for (j = 0; j < content->count; j++) {
